package com.pgpool.tests;


import com.pgpool.domain.AuthData;

import java.sql.*;
import java.util.Random;

public class Issue231_Z_1 extends PgpoolTest {
	public static final int NUM_INSERTS = 10;

	final String TEST_QUERY = "SELECT typinput='array_in'::regproc, typtype   FROM pg_catalog.pg_type   LEFT   JOIN (select ns.oid as nspoid, ns.nspname, r.r           from pg_namespace as ns           join ( select s.r, (current_schemas(false))[s.r] as nspname                    from generate_series(1, array_upper(current_schemas(false), 1)) as s(r) ) as r          using ( nspname )        ) as sp     ON sp.nspoid = typnamespace  WHERE typname = '123'  ORDER BY sp.r, pg_type.oid DESC LIMIT 1";

	@Override
	public void runTest(AuthData authData) throws Exception {

		Random random = new Random(System.nanoTime());
		String url = String.format("jdbc:postgresql://%s:%d/%s?loglevel=2", authData.getPgpoolHostname(), authData.getPgpoolPort(), authData.getDatabaseName());
		try (Connection conn = DriverManager.getConnection(url, authData.getDatabaseLogin(), authData.getDatabasePasswd())) {


			conn.setAutoCommit(false);

			try (Statement stmtSimple = conn.createStatement();
			     PreparedStatement stmtPrep = conn.prepareStatement("select id,'backend_1' from write_table where id = ?")) {

				stmtSimple.executeQuery("SHOW TRANSACTION ISOLATION LEVEL");

				for (int k = 0; k < 2; k++)
					stmtSimple.executeQuery("select current_schema()");

				conn.commit();

				for (int k = 0; k < 2; k++) {
					stmtPrep.setInt(1, random.nextInt());
					stmtPrep.executeQuery().close();
				}

			}
			conn.commit();
			conn.commit();

			conn.setAutoCommit(true);
			executeSelectStatement(conn, "select current_schema()");

		} catch (SQLException ex) {


			throw new RuntimeException(ex);
		}
	}


	private void executeSelectStatement(Connection conn, String statement) throws Exception {


		try (PreparedStatement stmt = conn.prepareStatement(statement)) {
			for (int k = 0; k < 5; k++)
				System.out.println("run request [" + statement + "]");
			stmt.executeQuery().close();
		}

	}
}
